.nav-color{
    background-color: #EEEEEE;
}

.nav-margin{
    margin-left: -25px;
    margin-right: -25px;
}

#collapseForm{
    background-color: #EEEEEE;
}

#vue-app {
    margin-left: -36px;
    margin-right: -36px;
}

label::after{
    content: "" !important;
}

.pontilhado-meta{
    border-style: dashed;
    border-color: #0A5190;
    background-color: rgb(183, 234, 238);
    padding: 16px;
    padding-left: 60px;
    padding-right: 60px;
    color: #0A5190;
}

.pontilhado-recursos{
    border-style: dashed;
    border-color: #0A5190;
    background-color: rgb(183, 234, 238);
    color: #0A5190;
}

.add-meta{
    padding: 10px;
}

input::placeholder{
    color:#9ea2b0;
}

#btn-coluna{
    padding: 0%!important;
}

.input-style{
    width: 10rem!important;
    padding-top: 4%!important;
    border-color: #6d7278!important;
    background-color: #6d7278!important;
    color: white!important;
}

.margin-preview{
    margin-left:-17px!important;
    margin-right: -17px!important;
    margin-top: -17px!important;
}

.required {
    color: #dc3545;
}

.loading-container {
    position: absolute;
    top: 0px;
    left: 0px;
    right: 0px;
    bottom: 0px;
    text-align: center;
}
.loading-container .loading-backdrop {
    position: fixed;
    top: 0;
    left: 0;
    height: 100%;
    width: 100%;
    background-color: lightgray;
    opacity: 0.5;
    z-index: 9998;
}
.loading-container .loading {
    z-index: 9999;
    position: fixed;
    display: inline-block;
    background-color: white;
    padding: 20px 50px;
    border-radius: 12px;
    box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19);
    left: 50%;
    top: 50%;
    -ms-transform: translate(-50%,-50%);
    -moz-transform: translate(-50%,-50%);
    -webkit-transform: translate(-50%,-50%);
    transform: translate(-50%,-50%);
}

.loading-container .loading .loading-icon {
    margin-bottom: 8px;
}
