{% ckan_extends %}

{% block scripts %}
{{ super() }}
<script src="https://cdn.jsdelivr.net/npm/vue@2.7.13/dist/vue.js"></script>
<script src="https://cdn.jsdelivr.net/npm/axios/dist/axios.min.js"></script>
<script src="/datapackage_creator/js/package_read.js"></script>
{% endblock %}